# yxr-codeforces-core

python3.8+ ([typing.Protocol](https://docs.python.org/3/library/typing.html#typing.Protocol) New in version 3.8.)

| feature                          | code | inline example doc | unit test | e2e test |
| -------------------------------- | ---- | ------------------ | --------- | -------- |
| account login                    | ✅    | ✅                  | ✅         | ✅        |
| submit code                      | ✅    | ✅                  | ✅         | ❌        |
| submission websocket             | ✅    | ✅                  | ✅         | ❌        |
| my submission page               | ✅    | ✅                  | ❌         | ❌        |
| contest register                 | ✅    | ✅                  | ❌         | ✅        |
| contest list                     | ✅    | ✅                  | ✅         | ❌        |
| contest meta                     | ✅    | ✅                  | ✅         | ❌        |
| contest standing(common/friends) | ✅    | ✅                  | ✅         | ❌        |
| problems                         | ✅    | ✅                  | ✅         | ❌        |
| specific problem                 | ✅    | ✅                  | ✅         | ❌        |
| language list                    | ✅    | ✅                  | ✅         | ❌        |
| pid/url parser                   | ✅    | ✅                  | ❌         | ❌        |
| domain 2 ip dig tool             | ❌    | ❌                  | ❌         | ❌        |

## Docs

[User](https://cromarmot.github.io/yxr-codeforces-core/user/index.html)

[Developer](https://cromarmot.github.io/yxr-codeforces-core/dev/index.html)
